@@ -108,13 +108,24 @@ def cli(verbose):
         multiple=True,
         help = "Coverage labels to consider for this run."
 )
-@click.option('--xlen','-x',type=click.Choice(['32','64']),default='32',help="XLEN value for the ISA.")
+@click.option('--xlen','-x',
+        type=click.Choice(['32','64']),
+        default='32',
+        help="XLEN value for the ISA."
+)
+@click.option('--no-count',
+        is_flag = True,
+        help = "This option removes hit coverpoints during coverage computation"
+)
+@click.option('--procs', '-p',
+        default = 1,
+        help = 'Set number of processes to calculate coverage'
+)
+
 def coverage(elf,trace_file, window_size, cgf_file, detailed,parser_name, decoder_name, parser_path, decoder_path,output_file, test_label,
-        sig_label, dump,cov_label, xlen):
+        sig_label, dump,cov_label, xlen, no_count, procs):
     isac(output_file,elf,trace_file, window_size, expand_cgf(cgf_file,int(xlen)), parser_name, decoder_name, parser_path, decoder_path, detailed, test_label,
-            sig_label, dump, cov_label, int(xlen))
-
-
+            sig_label, dump, cov_label, int(xlen), no_count, procs)
 
 @cli.command(help = "Merge given coverage files.")
 @click.argument(
@@ -174,8 +185,6 @@ def normalize(cgf_file,output_file,xlen):
     with open(output_file,"w") as outfile:
         utils.dump_yaml(expand_cgf(cgf_file,int(xlen)),outfile)
 
-
-
 @cli.command(help = 'Setup the plugin which uses the information from RISCV Opcodes repository to decode.')
 @click.option('--url',
                 type = str,
@@ -220,4 +229,3 @@ def setup(url,branch, plugin_path, rvop_path):
     logger.debug("Copying plugin files.")
     shutil.copy(plugin_file,plugin_path)
     shutil.copy(constants_file,plugin_path)
-
